#!/usr/bin/env python

from time import sleep
import RPi.GPIO as GPIO

DIRR = 8  # Direction GPIO Pin
DIRL = 4  # Direction GPIO Pin
STEPR = 7  # Step GPIO Pin
STEPL = 14  # Step GPIO Pin
CW = 1     # Clockwise Rotation
CCW = 0    # Counterclockwise Rotation
SPR = 200   # Steps per Revolution

def setup_GPIO() :
  GPIO.setmode(GPIO.BCM)
  GPIO.setup(DIRR, GPIO.OUT)
  GPIO.setup(DIRL, GPIO.OUT)

  GPIO.setup(STEPR, GPIO.OUT)
  GPIO.setup(STEPL, GPIO.OUT)

def cleanup_GPIO() :
  GPIO.cleanup()

delay = .005

def steps(value) :
  return int(value)

def cm_to_steps(value) :
  return int(value/20.0*SPR)

def angle_to_steps(value) :
  return (int)(value/100.0*SPR)

def drive_hw(rdir, ldir, steps) :
  GPIO.output(DIRR, rdir)
  GPIO.output(DIRL, ldir)
  for x in range(steps):
    GPIO.output(STEPR, GPIO.HIGH)
    GPIO.output(STEPL, GPIO.HIGH)
    sleep(delay)
    GPIO.output(STEPR, GPIO.LOW)
    GPIO.output(STEPL, GPIO.LOW)
    sleep(delay)


def drive(dirName, value, unit) :

  if unit and unit != 'cm' :
    print("drive: unknown distance")
    return

  if dirName == '':
    if value > 0:
      dirName = 'forward'

    if value < 0:
      dirName = 'backward'
      value = -value

  if dirName == 'forward':
    print("drive: forward %s cm " % value)
    drive_hw(CCW, CW, cm_to_steps(value))

  if dirName == 'backward':
    print("drive: backward %s cm " % value)
    drive_hw(CW, CCW, cm_to_steps(value))


def rotate(dirName, value, unit) :

  if unit and unit != 'grad' :
    print("rotate: unknown angle")
    return

  if dirName == '':
    if value > 0:
      dirName = 'right'
    if value < 0:
      dirName = 'left'
      value = -value

  if dirName == 'right':
    print("rotate: right %s grad " % value)
    drive_hw(CW, CW, angle_to_steps(value))

  if dirName == 'left':
    print("rotate: left %s grad " % value)
    drive_hw(CCW, CCW, angle_to_steps(value))


def test_drive() :

  drive('forward', 5, 'cm')
  sleep(.5)
  drive('backward', 5, 'cm')
  sleep(.5)

  rotate('right', 90, 'grad')
  sleep(.5)
  rotate('left', 90, 'grad')
  sleep(.5)
  rotate('left', 90, 'grad')
  sleep(.5)
  rotate('right', 90, 'grad')
  sleep(.5)  
  rotate('', 45, 'grad')
  sleep(.5)  
  rotate('', -45, 'grad')  
  sleep(.5)


if __name__ == "__main__":
  setup_GPIO()
  test_drive()
  cleanup_GPIO()

